@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.65';
+our $VERSION = '0.66';
 
 use Dist::Zilla 6.0;
 
@@ -24,6 +24,7 @@ use Dist::Zilla::Plugin::DROLSKY::Contributors;
 use Dist::Zilla::Plugin::DROLSKY::License;
 use Dist::Zilla::Plugin::DROLSKY::TidyAll;
 use Dist::Zilla::Plugin::DROLSKY::VersionProvider;
+use Dist::Zilla::Plugin::DROLSKY::WeaverConfig;
 use Dist::Zilla::Plugin::GenerateFile::FromShareDir;
 use Dist::Zilla::Plugin::Git::Check;
 use Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts;
@@ -648,11 +649,14 @@ sub _extra_test_plugins {
 }
 
 sub _pod_weaver_plugin {
-    [
-        SurgicalPodWeaver => {
-            config_plugin => '@DROLSKY',
-        },
-    ];
+    return (
+        [
+            SurgicalPodWeaver => {
+                config_plugin => '@DROLSKY',
+            },
+        ],
+        'DROLSKY::WeaverConfig',
+    );
 }
 
 sub _readme_md_plugin {
@@ -754,7 +758,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.65
+version 0.66
 
 =head1 DESCRIPTION
 
