@@ -3,7 +3,7 @@ package Pod::Weaver::PluginBundle::DROLSKY;
 use strict;
 use warnings;
 
-our $VERSION = '0.65';
+our $VERSION = '0.66';
 
 use namespace::autoclean -also => ['_exp'];
 
@@ -43,13 +43,15 @@ sub configure {
     my $podweaver_plugin
         = ${ peek_sub( \&Dist::Zilla::Plugin::PodWeaver::weaver )->{'$self'}
         };
-    my $licence_plugin = $podweaver_plugin
-        && $podweaver_plugin->zilla->plugin_named('@Author::DROLSKY/License');
-    my $licence_filename
-        = $licence_plugin ? $licence_plugin->filename : 'LICENCE';
 
-    my $include_donations
-        = $podweaver_plugin->zilla->copyright_holder =~ /Rolsky/;
+    my $zilla          = $podweaver_plugin->zilla;
+    my $license_plugin = $zilla->plugin_named('@Author::DROLSKY/License');
+    my $license_filename
+        = $license_plugin ? $license_plugin->filename : 'LICENSE';
+
+    my $config = $zilla->plugin_named('@DROLSKY/DROLSKY::WeaverConfig');
+    my $include_donations = $zilla->copyright_holder =~ /Rolsky/
+        && $config->include_donations_pod;
 
     return (
         '@CorePrep',
@@ -152,7 +154,7 @@ DONATIONS
         [
             'Legal' => {
                 ':version' => '4.011',
-                header     => 'COPYRIGHT AND ' . $licence_filename
+                header     => 'COPYRIGHT AND ' . $license_filename
             }
         ],
         [ 'Region' => 'footer' ],
@@ -238,7 +240,7 @@ Pod::Weaver::PluginBundle::DROLSKY - A plugin bundle for pod woven by DROLSKY
 
 =head1 VERSION
 
-version 0.65
+version 0.66
 
 =head1 SYNOPSIS
 
@@ -321,7 +323,7 @@ following F<weaver.ini>, minus some optimizations:
 
     [Legal]
     :version = 4.011
-    header = COPYRIGHT AND <licence filename>
+    header = COPYRIGHT AND <license filename>
 
     [Region / footer]
 
@@ -367,7 +369,7 @@ be possible without updates to L<Pod::Weaver>.)
 
 =head1 OVERRIDING A SPECIFIC SECTION
 
-This F<weaver.ini> will let you use a custom C<COPYRIGHT AND LICENCE> section
+This F<weaver.ini> will let you use a custom C<COPYRIGHT AND LICENSE> section
 and still use the plugin bundle:
 
     [@Author::DROLSKY]
